aboutsummaryrefslogtreecommitdiffstats
path: root/src/keymap.c
diff options
context:
space:
mode:
authorLars Magne Ingebrigtsen <[email protected]>2011-07-12 23:12:36 +0200
committerLars Magne Ingebrigtsen <[email protected]>2011-07-12 23:12:36 +0200
commitb3dadd7683d3d66630d5be72b222f3931381dad0 (patch)
tree20fecdd1d265fa123543c5c8f8b8b7424bbff193 /src/keymap.c
parent0cf346886f0ac320e92e3b5df32508bc6fcfe576 (diff)
(syms_of_keymap): Clarify that "modifier" is "modifier key"
Fixes: debbugs:4257
Diffstat (limited to 'src/keymap.c')
-rw-r--r--src/keymap.c8
1 files changed, 4 insertions, 4 deletions
diff --git a/src/keymap.c b/src/keymap.c
index d33af68be4..0169276bef 100644
--- a/src/keymap.c
+++ b/src/keymap.c
@@ -3712,11 +3712,11 @@ the same way. The "active" keymaps in each alist are used before
Vemulation_mode_map_alists = Qnil;
DEFVAR_LISP ("where-is-preferred-modifier", Vwhere_is_preferred_modifier,
- doc: /* Preferred modifier to use for `where-is'.
+ doc: /* Preferred modifier key to use for `where-is'.
When a single binding is requested, `where-is' will return one that
-uses this modifier if possible. If nil, or if no such binding exists,
-bindings using keys without modifiers (or only with meta) will be
-preferred. */);
+uses this modifier key if possible. If nil, or if no such binding
+exists, bindings using keys without modifiers (or only with meta) will
+be preferred. */);
Vwhere_is_preferred_modifier = Qnil;
where_is_preferred_modifier = 0;